@@ -11,3 +11,6 @@
 #
 
 from .furl import *  # noqa
+from .__version__ import (  # noqa
+    __title__, __version__, __license__, __author__, __contact__, __url__,
+    __description__)
